# basic sh script for building a gromacs simulation
# works nicely with native output of acpype.
# automatically updates topology file 
# takes 3 parameters 	-n: number of molecules
#						-b: box dimensions
#						-t: number of times to try
# box volume (-b^3) should be > ~2 -n usually.
shopt -s extglob

while getopts n:b:t: flag
do
    case "${flag}" in
        n) nmols=${OPTARG};;
		b) box=${OPTARG};;
		t) try=${OPTARG};;
    esac
done

echo "inserting $nmols molecules...";

module add gromacs/2019.2gpu

gmx insert-molecules -ci *_GMX.gro -nmol $nmols -rot xyz -box $box $box $box -o simubox -try $try
sed 's/ 1/ '$nmols'/g' *GMX.top > topology.top

loc=${PWD##*/} # loc is the name prefix we'll use for jobs.

qsub -N $loc+"GROMPP1" ../sh_files/GROMPP1.job
qsub -N $loc+"EM1" -hold_jid $loc+"GROMPP1" ../sh_files/EM.job

qsub -N $loc+"GROMPP2" -hold_jid $loc+"EM1" ../sh_files/GROMPP2.job
qsub -N $loc+"EM2" -hold_jid $loc+"GROMPP2" ../sh_files/EM.job

#once energy min is finished, we run GROMPP to build a .tpr for equilibration
#we can execute this on the GPU (P100)

qsub -N $loc+"GROMPP5" -hold_jid $loc+"EM2" ../sh_files/GROMPP5.job
qsub -N $loc+"EQ1" -hold_jid $loc+"GROMPP5" ../sh_files/GPU.job

qsub -N $loc+"GROMPP6" -hold_jid $loc+"EQ1" ../sh_files/GROMPP6.job
qsub -N $loc+"EQ2" -hold_jid $loc+"GROMPP6" ../sh_files/GPU.job

qsub -N $loc+"GROMPPefield" -hold_jid $loc+"EQ2" ../sh_files/GROMPPefield.job
qsub -N $loc+"Efield" -hold_jid $loc+"GROMPPefield" ../sh_files/GPU.job

#now we build a .tpr for a production MD run, executing on GPU (P100)
qsub -N $loc+"GROMPP7" -hold_jid $loc+"Efield" ../sh_files/GROMPP7.job
qsub -N $loc+"MD1" -hold_jid $loc+"GROMPP7" ../sh_files/GPU_MD.job
qsub -N $loc+"MD2" -hold_jid $loc+"MD1" ../sh_files/GPU_MD_continue.job
qsub -N $loc+"MD3" -hold_jid $loc+"MD2" ../sh_files/GPU_MD_continue.job
qsub -N $loc+"MD4" -hold_jid $loc+"MD3" ../sh_files/GPU_MD_continue.job

#clean shit up
rm *AC.frcmod *AC.inpcrd *AC.lib *AC.prmtop *CHARMM.inp *CHARMM.prm *CHARMM.rtf *CNS.inp *CNS.par *CNS.top *.pkl

